@@ -17,7 +17,7 @@
 #
 
 """Mechanisms for asynchronous call result in single-thread environment."""
-from __future__ import print_function, unicode_literals
+
 
 import collections
 import types
@@ -546,7 +546,7 @@ class VPendingList(VPending):
             self.__fire_callback()
         else:
             self.__pending_list = {}
-            for i in xrange(len(pending_list)):
+            for i in range(len(pending_list)):
                 p = pending_list[i]
                 self.__pending_list[i] = p
                 p.add_callpair(self.__callback, self.__failback,
@@ -561,7 +561,7 @@ class VPendingList(VPending):
         self.cancel()
 
     def cancel(self):
-        for p in self.__pending_list.values():
+        for p in list(self.__pending_list.values()):
             p.cancel()
         super(VPendingList, self).cancel()
 
