@@ -17,7 +17,7 @@
 #
 
 """Implements (a subset of standards for) :term:`X.509` certificates."""
-from __future__ import print_function, unicode_literals
+
 
 import base64
 import datetime
@@ -435,7 +435,7 @@ class VX509Certificate(object):
         intended mainly for internal use.
 
         """
-        _ctag = lambda(n): VASN1Tag(VASN1Tag.CONTEXT, n)
+        _ctag = lambda n: VASN1Tag(VASN1Tag.CONTEXT, n)
         _def_tbs = TBSCertificate()
         tbs_cert = _def_tbs.create()
         if not_before is None:
@@ -732,7 +732,7 @@ class VX509CertificationRequest(object):
             The 'attributes' property is not properly supported.
 
         """
-        _ctag = lambda(n): VASN1Tag(VASN1Tag.CONTEXT, n)
+        _ctag = lambda n: VASN1Tag(VASN1Tag.CONTEXT, n)
         req_info = CertificationRequestInfo().create()
         req_info.c_app('version', 0)()
         req_info.append(subject.export(), name='subject')
@@ -964,10 +964,10 @@ class VX509Name(dict):
 
     def __init__(self, **kargs):
         super(VX509Name, self).__init__()
-        for name, value in kargs.items():
+        for name, value in list(kargs.items()):
             if isinstance(value, bytes):
-                value = unicode(bytes)
-            if not isinstance(value, unicode):
+                value = str(bytes)
+            if not isinstance(value, str):
                 raise VCryptoException('Values must be unicode')
             oid = self.oid(name)
             if oid:
@@ -1014,7 +1014,7 @@ class VX509Name(dict):
                 cls.__validate_criteria(len(item) == 1)
                 key, value = tuple(item)[0]
                 cls.__validate_type(key, VObjectIdentifier)
-                cls.__validate_type(value, unicode)
+                cls.__validate_type(value, str)
                 name[key] = value
             if bytes_read and orig_fmt != VX509Format.ASN1:
                 return (name, num_read)
@@ -1031,7 +1031,7 @@ class VX509Name(dict):
 
         """
         asn1data = RDNSequence().create()
-        for key, val in self.items():
+        for key, val in list(self.items()):
             _pair = AttributeTypeAndValue().create()
             _pair.append(key, name='type')
             _pair.append(val, name='value')
