@@ -17,10 +17,10 @@
 #
 
 """.. Framework for resolving :term:`VRI` identifiers."""
-from __future__ import print_function, unicode_literals
 
-import urllib
-import urlparse
+
+import urllib.request, urllib.parse, urllib.error
+import urllib.parse
 
 from versile.internal import _vexport, _v_silent, _val2b, _s2b, _pyver
 from versile.common.util import VConfig, VLockable, VResult, VResultException
@@ -300,7 +300,7 @@ class VUrl(object):
                     if not isinstance(p, str):
                         raise VUrlException('VRI path must be strings')
                 if query_kargs:
-                    for k in query_kargs.keys():
+                    for k in list(query_kargs.keys()):
                         if not isinstance(k, str):
                             raise VUrlException('VRI keyword must be string')
 
@@ -319,7 +319,7 @@ class VUrl(object):
                         return 'bool:True'
                     else:
                         return 'bool:False'
-                elif isinstance(val, (int, long)):
+                elif isinstance(val, int):
                     return 'int:%s' % str(val)
                 elif (val.startswith('bool:') or val.startswith('int:')
                       or val.startswith('str:')):
@@ -332,7 +332,7 @@ class VUrl(object):
                 query_args = tuple()
             _kargs = dict()
             if query_kargs:
-                for key, val in query_kargs.items():
+                for key, val in list(query_kargs.items()):
                     _kargs[encoder(key)] = _lazy(val)
             query_kargs = _kargs
 
@@ -577,7 +577,7 @@ class VUrlResolver(VLockable):
 
         """
         try:
-            return urllib.quote(s)
+            return urllib.parse.quote(s)
         except:
             raise VUrlException()
 
@@ -593,7 +593,7 @@ class VUrlResolver(VLockable):
 
         """
         try:
-            return urllib.unquote(s)
+            return urllib.parse.unquote(s)
         except:
             raise VUrlException('Could not decode from percent-encoded UTF8')
 
@@ -613,7 +613,7 @@ class VUrlData(object):
     def __init__(self, url):
         if _pyver == 3 and not isinstance(url, str):
             raise VUrlException('VRI must be a string')
-        parsed = urlparse.urlparse(url)
+        parsed = urllib.parse.urlparse(url)
 
         self._scheme = parsed.scheme.lower()
 
@@ -674,7 +674,7 @@ class VUrlData(object):
                             value = self.convert_value(value)
                         except ValueError:
                             raise VUrlException('Value conversion error')
-                        q_kargs.append([decoder(e) for e in key, value])
+                        q_kargs.append([decoder(e) for e in (key, value)])
                     else:
                         value = decoder(arg)
                         try:
