@@ -17,7 +17,7 @@
 #
 
 """Reactor-based implementation of the :term:`VEC` specification."""
-from __future__ import print_function, unicode_literals
+
 
 import collections
 from threading import Lock
@@ -776,7 +776,7 @@ class VEntitySerializer(object):
                 self.__ep_queue.clear()
             elif max_prod > 0:
                 prod = []
-                for i in xrange(max_prod):
+                for i in range(max_prod):
                     if self.__ep_queue:
                         prod.append(self.__ep_queue.popleft())
                     else:
@@ -833,7 +833,7 @@ class VEntitySerializer(object):
                     _allowed.append(b'.')
                 else:
                     # Using integers for python3
-                    _allowed = range(ord('0'), ord('9')+1) + [ord('.')]
+                    _allowed = list(range(ord('0'), ord('9')+1)) + [ord('.')]
                 for char in version:
                     if char not in _allowed:
                         raise VIOError('Illegal protocol version number')
