@@ -16,7 +16,7 @@
 # License along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 """Reactor based implementation of the :term:`VTS` specification."""
-from __future__ import print_function, unicode_literals
+
 
 import weakref
 
@@ -1159,7 +1159,7 @@ class VSecure(object):
                                 range(ord('0'), ord('9')+1)] + [b'.']
                 else:
                     # Using integers for python3
-                    _allowed = range(ord('0'), ord('9')+1) + [ord('.')]
+                    _allowed = list(range(ord('0'), ord('9')+1)) + [ord('.')]
                 for char in version:
                     if char not in _allowed:
                         raise VIOError('Illegal protocol version number')
@@ -1239,10 +1239,10 @@ class VSecureClient(VSecure):
                  s_pubdata, s_credentials, max_keylen, hshake_lim) = data
             except ValueError:
                 raise VIOError('Could not unpack data')
-            if not (isinstance(hmac_name, unicode)
-                    and isinstance(cipher_name, unicode)
-                    and isinstance(cipher_mode, unicode)
-                    and isinstance(hash_name, unicode)
+            if not (isinstance(hmac_name, str)
+                    and isinstance(cipher_name, str)
+                    and isinstance(cipher_mode, str)
+                    and isinstance(hash_name, str)
                     and isinstance(s_rand, bytes)
                     and isinstance(s_pubdata, tuple) and len(s_pubdata) == 2):
                 raise VIOError('Illegal data types')
@@ -1255,7 +1255,7 @@ class VSecureClient(VSecure):
             if not hash_name in self._hashes:
                 raise VIOError('Invalid hash name')
             s_pub_name, s_pub_keydata = s_pubdata
-            if not isinstance(s_pub_name, unicode):
+            if not isinstance(s_pub_name, str):
                 raise VIOError('Invalid public key cipher name')
             if (max_keylen is None or
                 isinstance(max_keylen, int) and max_keylen > 0):
@@ -1461,17 +1461,17 @@ class VSecureServer(VSecure):
                 if not (isinstance(cipher, tuple) and len(cipher) == 2):
                     raise VIOError('Illegal ciphers list')
                 c_name, c_modes = cipher
-                if not (isinstance(c_name, unicode) and
+                if not (isinstance(c_name, str) and
                         isinstance(c_modes, tuple)):
                     raise VIOError('Illegal ciphers list')
                 for c_mode in c_modes:
-                    if not isinstance(c_mode, unicode):
+                    if not isinstance(c_mode, str):
                         raise VIOError('Illegal ciphers list')
             for _hash in hhashes:
-                if not isinstance(_hash, unicode):
+                if not isinstance(_hash, str):
                     raise VIOError('Illegal handshake hash list')
             for _hash in hashes:
-                if not isinstance(_hash, unicode):
+                if not isinstance(_hash, str):
                     raise VIOError('Illegal hash list')
             if len(c_rand) < 32:
                 raise VIOError('Minimum 32 bytes random data required')
@@ -1587,7 +1587,7 @@ class VSecureServer(VSecure):
                 if not (isinstance(c_keydata, tuple) and len(c_keydata) == 2):
                     raise VIOError('Illegal data types')
                 c_pub_name, c_pub_keydata = c_keydata
-                if not isinstance(c_pub_name, unicode):
+                if not isinstance(c_pub_name, str):
                     raise VIOError('Invalid public key cipher name')
                 try:
                     if c_pub_name not in self._config.pub_ciphers:
